@@ -91,7 +91,7 @@ ListRoutesPaginatorName = Literal["list_routes"]
 ListServicesPaginatorName = Literal["list_services"]
 NetworkFabricTypeType = Literal["TRANSIT_GATEWAY"]
 ProxyTypeType = Literal["API_GATEWAY"]
-RouteActivationStateType = Literal["ACTIVE"]
+RouteActivationStateType = Literal["ACTIVE", "INACTIVE"]
 RouteStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "INACTIVE", "UPDATING"]
 RouteTypeType = Literal["DEFAULT", "URI_PATH"]
 ServiceEndpointTypeType = Literal["LAMBDA", "URL"]
@@ -167,6 +167,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -277,6 +278,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -333,6 +335,7 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshiftserverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
